==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/NotifyEJB/src/com/clustercontrol/notify/factory/ModifySystemNotify.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.notify.factory;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Date;

import javax.ejb.CreateException;
import javax.ejb.FinderException;
import javax.ejb.RemoveException;
import javax.jms.JMSException;
import javax.naming.NamingException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.accesscontrol.factory.AccessLock;
import com.clustercontrol.notify.bean.NotifyEventInfo;
import com.clustercontrol.notify.bean.NotifyInfo;
import com.clustercontrol.notify.ejb.entity.SystemNotifyEventInfoLocal;
import com.clustercontrol.notify.ejb.entity.SystemNotifyEventInfoUtil;
import com.clustercontrol.notify.ejb.entity.SystemNotifyInfoLocal;
import com.clustercontrol.notify.ejb.entity.SystemNotifyInfoUtil;
import com.clustercontrol.util.apllog.AplLogger;

/**
 * ƥξ󹹿饹
 *
 * @version 2.1.0
 * @since 2.1.0
 */
public class ModifySystemNotify {
	
	protected static Log m_log = LogFactory.getLog( ModifySystemNotify.class );
	
	/**
	 * ƥξ򹹿
	 * 
	 * @param info
	 * @return 硢true
	 * @throws CreateException
	 * @throws FinderException
	 * @throws RemoveException
	 * @throws NamingException
	 * @throws JMSException
	 */
	@SuppressWarnings("unchecked")
	public boolean modify(NotifyInfo info) throws CreateException, FinderException, RemoveException, NamingException, JMSException {
		//å
		AccessLock.lock(AccessLock.NOTIFY);
		
//		SendQueue queue = null;
		try 
		{
			// ƥξ
			SystemNotifyInfoLocal notify = 
				SystemNotifyInfoUtil.getLocalHome().findByPrimaryKey(info.getNotifyId());
			
			// ƥξ򹹿
			if(notify != null){
				notify.setDescription(info.getDescription());
				notify.setStatusFlg(info.getStatusFlg());
				notify.setStatusValidPeriod(info.getStatusValidPeriod());
				notify.setStatusInvalidFlg(info.getStatusInvalidFlg());
				notify.setStatusUpdatePriority(info.getStatusUpdatePriority());
				notify.setEventFlg(info.getEventFlg());
				notify.setInhibitionFlg(info.getInhibitionFlg());
				notify.setInhibitionFrequency(info.getInhibitionFrequency());
				notify.setInhibitionPeriod(info.getInhibitionPeriod());
				notify.setUpdateDate(new Timestamp(new Date().getTime()));
			}
			Collection ct = notify.getSystemNotifyEventInfo();
			
			// ƥΥ٥Ⱦ
			DeleteSystemNotify delete = new DeleteSystemNotify();
			delete.deleteEvents(ct);
			
			// ƥΥ٥Ⱦ
			ArrayList<NotifyEventInfo> eventList = info.getNotifyEventInfo();
			ArrayList<SystemNotifyEventInfoLocal> eventLocalList = new ArrayList<SystemNotifyEventInfoLocal>();
			
			NotifyEventInfo event = null;
			for(int index=0; index<eventList.size(); index++){
				event = (NotifyEventInfo)eventList.get(index);
				if(event != null){
					SystemNotifyEventInfoLocal local = 
						SystemNotifyEventInfoUtil.getLocalHome().create(
								info.getNotifyId(),
								event.getPriority(),
								event.getEventNormalFlg(),
								event.getEventNormalState(),
								event.getEventInhibitionFlg(),
								event.getEventInhibitionState(),
								event.getMailFlg(),
								event.getMailAddress());
					eventLocalList.add(local);
				}
			}
			if(eventLocalList != null){
				ct.addAll(eventLocalList);
				notify.setSystemNotifyEventInfo(ct);
			}
			
//			NotifyInfoContext context = new NotifyInfoContext(NotifyInfoContext.TYPE_UPDATE, info.getNotifyId(), info);
//			
//			// ξ󥭥å򹹿
//			queue = new SendQueue(QueueConstant.QUEUE_NAME_LOG);
//			queue.put(context);
//			queue.terminate();
			
		} catch (CreateException e) {
			AplLogger apllog = new AplLogger("NOTIFY", "notify");
			String[] args = { info.getNotifyId() };
			apllog.put("SYS", "002", args);
			m_log.debug("modify():" + e.getMessage());
			throw e;
		} catch (FinderException e) {
			AplLogger apllog = new AplLogger("NOTIFY", "notify");
			String[] args = { info.getNotifyId() };
			apllog.put("SYS", "002", args);
			m_log.debug("modify():" + e.getMessage());
			throw e;
		} catch (RemoveException e) {
			AplLogger apllog = new AplLogger("NOTIFY", "notify");
			String[] args = { info.getNotifyId() };
			apllog.put("SYS", "002", args);
			m_log.debug("modify():" + e.getMessage());
			throw e;
		} catch (NamingException e) {
			AplLogger apllog = new AplLogger("NOTIFY", "notify");
			String[] args = { info.getNotifyId() };
			apllog.put("SYS", "002", args);
			m_log.debug("modify():" + e.getMessage());
			throw e;
//			} catch (JMSException e) {
//			AplLogger apllog = new AplLogger("NOTIFY", "notify");
//			String[] args = { info.getNotifyId() };
//			apllog.put("SYS", "002", args);
//			m_log.debug("modify():" + e.getMessage());
//			throw e;
//			}
//			finally{
//			if(queue != null){
//			queue.terminate();	
//			}
		}
		return true;
	}
	
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/NotifyEJB/src/com/clustercontrol/notify/factory/ModifySystemNotify.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.notify.factory;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Date;

import javax.ejb.CreateException;
import javax.ejb.FinderException;
import javax.ejb.RemoveException;
import javax.jms.JMSException;
import javax.naming.NamingException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.accesscontrol.factory.AccessLock;
import com.clustercontrol.notify.bean.NotifyEventInfo;
import com.clustercontrol.notify.bean.NotifyInfo;
import com.clustercontrol.notify.ejb.entity.SystemNotifyEventInfoLocal;
import com.clustercontrol.notify.ejb.entity.SystemNotifyEventInfoUtil;
import com.clustercontrol.notify.ejb.entity.SystemNotifyInfoLocal;
import com.clustercontrol.notify.ejb.entity.SystemNotifyInfoUtil;
import com.clustercontrol.util.apllog.AplLogger;

/**
 * システム通知情報更新クラス
 *
 * @version 2.1.0
 * @since 2.1.0
 */
public class ModifySystemNotify {
	
	protected static Log m_log = LogFactory.getLog( ModifySystemNotify.class );
	
	/**
	 * システム通知情報を更新
	 * 
	 * @param info
	 * @return 更新に成功した場合、true
	 * @throws CreateException
	 * @throws FinderException
	 * @throws RemoveException
	 * @throws NamingException
	 * @throws JMSException
	 */
	@SuppressWarnings("unchecked")
	public boolean modify(NotifyInfo info) throws CreateException, FinderException, RemoveException, NamingException, JMSException {
		//アクセスロック
		AccessLock.lock(AccessLock.NOTIFY);
		
//		SendQueue queue = null;
		try 
		{
			// システム通知情報を取得
			SystemNotifyInfoLocal notify = 
				SystemNotifyInfoUtil.getLocalHome().findByPrimaryKey(info.getNotifyId());
			
			// システム通知情報を更新
			if(notify != null){
				notify.setDescription(info.getDescription());
				notify.setStatusFlg(info.getStatusFlg());
				notify.setStatusValidPeriod(info.getStatusValidPeriod());
				notify.setStatusInvalidFlg(info.getStatusInvalidFlg());
				notify.setStatusUpdatePriority(info.getStatusUpdatePriority());
				notify.setEventFlg(info.getEventFlg());
				notify.setInhibitionFlg(info.getInhibitionFlg());
				notify.setInhibitionFrequency(info.getInhibitionFrequency());
				notify.setInhibitionPeriod(info.getInhibitionPeriod());
				notify.setUpdateDate(new Timestamp(new Date().getTime()));
			}
			Collection ct = notify.getSystemNotifyEventInfo();
			
			// システム通知イベント情報を削除
			DeleteSystemNotify delete = new DeleteSystemNotify();
			delete.deleteEvents(ct);
			
			// システム通知イベント情報を挿入
			ArrayList<NotifyEventInfo> eventList = info.getNotifyEventInfo();
			ArrayList<SystemNotifyEventInfoLocal> eventLocalList = new ArrayList<SystemNotifyEventInfoLocal>();
			
			NotifyEventInfo event = null;
			for(int index=0; index<eventList.size(); index++){
				event = (NotifyEventInfo)eventList.get(index);
				if(event != null){
					SystemNotifyEventInfoLocal local = 
						SystemNotifyEventInfoUtil.getLocalHome().create(
								info.getNotifyId(),
								event.getPriority(),
								event.getEventNormalFlg(),
								event.getEventNormalState(),
								event.getEventInhibitionFlg(),
								event.getEventInhibitionState(),
								event.getMailFlg(),
								event.getMailAddress());
					eventLocalList.add(local);
				}
			}
			if(eventLocalList != null){
				ct.addAll(eventLocalList);
				notify.setSystemNotifyEventInfo(ct);
			}
			
//			NotifyInfoContext context = new NotifyInfoContext(NotifyInfoContext.TYPE_UPDATE, info.getNotifyId(), info);
//			
//			// 通知情報キャッシュを更新
//			queue = new SendQueue(QueueConstant.QUEUE_NAME_LOG);
//			queue.put(context);
//			queue.terminate();
			
		} catch (CreateException e) {
			AplLogger apllog = new AplLogger("NOTIFY", "notify");
			String[] args = { info.getNotifyId() };
			apllog.put("SYS", "002", args);
			m_log.debug("modify():" + e.getMessage());
			throw e;
		} catch (FinderException e) {
			AplLogger apllog = new AplLogger("NOTIFY", "notify");
			String[] args = { info.getNotifyId() };
			apllog.put("SYS", "002", args);
			m_log.debug("modify():" + e.getMessage());
			throw e;
		} catch (RemoveException e) {
			AplLogger apllog = new AplLogger("NOTIFY", "notify");
			String[] args = { info.getNotifyId() };
			apllog.put("SYS", "002", args);
			m_log.debug("modify():" + e.getMessage());
			throw e;
		} catch (NamingException e) {
			AplLogger apllog = new AplLogger("NOTIFY", "notify");
			String[] args = { info.getNotifyId() };
			apllog.put("SYS", "002", args);
			m_log.debug("modify():" + e.getMessage());
			throw e;
//			} catch (JMSException e) {
//			AplLogger apllog = new AplLogger("NOTIFY", "notify");
//			String[] args = { info.getNotifyId() };
//			apllog.put("SYS", "002", args);
//			m_log.debug("modify():" + e.getMessage());
//			throw e;
//			}
//			finally{
//			if(queue != null){
//			queue.terminate();	
//			}
		}
		return true;
	}
	
}
